Crate julep

Crate julep 

Native GUI renderer driven by a wire protocol over stdin/stdout.

This is a placeholder release to reserve the crate name. The first functional release will be 0.6.0.

See https://github.com/lincracy/julep for details.